library(openxlsx)
library(tidyverse)
library(viridis)
library(ggpubr)

# B: Firms handling Commodities
# Firm margins
exp_files <- list.files("output_20230221/b_firms/export_margins")
imp_files <- list.files("output_20230221/b_firms/import_margins")
exp_data <- lapply(exp_files, function(x) read.xlsx(paste0("output_20230221/b_firms/export_margins/", x)))
names(exp_data) <- exp_files
imp_data <- lapply(imp_files, function(x) read.xlsx(paste0("output_20230221/b_firms/import_margins/", x)))
names(imp_data) <- imp_files

# collect dataframes
exp_margins <- do.call("rbind", exp_data)
imp_margins <- do.call("rbind", imp_data)
margins <- rbind(exp_margins, imp_margins) %>%
	mutate(name = rownames(rbind(exp_margins, imp_margins))) %>%
	separate(name, into = c("group", "trade", "m1", "m2", "m3", "mtype", "sector"), sep = "_", fill = "right") %>%
	mutate(sector = ifelse(is.na(sector) & !is.na(mtype), mtype, sector),
		   sector = ifelse(is.na(sector) & is.na(mtype), m3, sector),
		   mtype = ifelse(X1 == "Statwert", "int", "ext"),
		   m3 = ifelse(!(m3 %in% c("prod", "ctry")), NA, m3),
		   m2 = ifelse(!(m2 %in% c("prod", "ctry")), NA, m2)) %>%
	select(-X1, -N)
rownames(margins) <- NULL

clean_margins <- margins %>%
	pivot_longer(cols = mean:p99, names_to = "stat") %>%
	mutate(sector = str_to_title(str_remove(sector, ".xlsx")),
		   stat = ifelse(stat == "sd", "SD", str_to_title(stat)))

# in table format
margins_tab <- clean_margins %>%
	pivot_wider(names_from = stat, values_from = value) %>%
	unite("name", m1:mtype) %>%
	mutate(name = ifelse(name == "firm_ctry_NA_ext", "Firm-Country Extensive", name),
		   name = ifelse(name == "firm_ctry_NA_int", "Firm-Country Intensive", name),
		   name = ifelse(name == "firm_prod_NA_ext", "Firm-Product Extensive", name),
		   name = ifelse(name == "firm_prod_NA_int", "Firm-Product Intensive", name),
		   name = ifelse(name == "firm_NA_NA_int", "Firm Intensive", name),
		   name = ifelse(name == "firm_ctry_prod_ext", "Firm-Country-Product Extensive", name),
		   name = ifelse(name == "firm_prod_ctry_ext", "Firm-Product-Country Extensive", name),
		   name = ifelse(name == "firm_prod_ctry_int", "Firm-Country-Product Intensive", name)) %>%
	rename(Sector = sector, Margin = name) %>%
	arrange(group, trade, factor(Margin, levels = c("Firm Intensive", "Firm-Country Extensive", "Firm-Country Intensive",
													"Firm-Product Extensive", "Firm-Product Intensive", "Firm-Country-Product Extensive",
													"Firm-Product-Country Extensive", "Firm-Country-Product Intensive")), Sector) %>%
	mutate(Margin = ifelse(Sector != "Manufacturing", NA, Margin))

margins_list <- lapply(c("exp", "imp"), function(y) {
	mapply(function(x, y) {filter(margins_tab, group == x, trade == y) %>% select(-trade, -group)},
		   x = c("all", "extra", "intra"), y = y, SIMPLIFY = FALSE)
	}) %>% unlist(recursive = FALSE)
names(margins_list) <- c(paste(names(margins_list)[1:3], "exp", sep = "_"),
						 paste(names(margins_list)[4:6], "imp", sep = "_"))

# write to file
hs <- createStyle(textDecoration = "bold", border = "TopLeftRight")
write.xlsx(margins_list, file = "clean_output/b_firms_34.xlsx", colNames = TRUE, borders = "columns", headerStyle = hs, colWidths = "auto")

# change borders and number format
wb <- loadWorkbook("clean_output/b_firms_34.xlsx")

border <- createStyle(border = "bottom")
number1 <- createStyle(numFmt = "COMMA")
number2 <- createStyle(numFmt = "0.0")

for (i in 1:6) {
	for (j in seq(6,41,5)) {
		addStyle(wb, sheet = i, style = border, cols = 1:9, rows = j, stack = TRUE)
		addStyle(wb, sheet = i, style = number1, cols = 3:9, rows = 2:41, stack = TRUE, gridExpand = TRUE)
		addStyle(wb, sheet = i, style = number2, cols = 3:4, rows = 7:11, stack = TRUE, gridExpand = TRUE)
		addStyle(wb, sheet = i, style = number2, cols = 3:4, rows = 17:21, stack = TRUE, gridExpand = TRUE)
		addStyle(wb, sheet = i, style = number2, cols = 3:4, rows = 27:36, stack = TRUE, gridExpand = TRUE)
	}
}

saveWorkbook(wb, "clean_output/b_firms_34.xlsx", overwrite = TRUE)


## Table 3
# Data
tab34_data <- clean_margins %>%
	pivot_wider(names_from = stat, values_from = value) %>%
	unite("name", m1:mtype) %>%
	mutate(sector = factor(sector, levels = c("Manufacturing", "Wholesale", "Retail", "Motor Vehicles", "Other")),
		   name = ifelse(name == "firm_ctry_NA_ext", "Firm-Country Extensive", name),
		   name = ifelse(name == "firm_ctry_NA_int", "Firm-Country Intensive (€)", name),
		   name = ifelse(name == "firm_prod_NA_ext", "Firm-Product Extensive", name),
		   name = ifelse(name == "firm_prod_NA_int", "Firm-Product Intensive (€)", name),
		   name = ifelse(name == "firm_NA_NA_int", "Firm Intensive (€)", name),
		   name = ifelse(name == "firm_ctry_prod_ext", "Firm-Country-Product Extensive", name),
		   name = ifelse(name == "firm_prod_ctry_ext", "Firm-Product-Country Extensive", name),
		   name = ifelse(name == "firm_prod_ctry_int", "Firm-Country-Product Intensive (€)", name),
		   name = factor(name, levels = c("Firm Intensive (€)", "Firm-Country Extensive", "Firm-Country Intensive (€)",
		   							   "Firm-Product Extensive", "Firm-Product Intensive (€)", "Firm-Country-Product Extensive",
		   							   "Firm-Country-Product Intensive (€)", "Firm-Product-Country Extensive")))

# Plot
all_exp_val <- ggplot(tab34_data %>% filter(group == "all", trade == "exp", str_detect(name, "Intensive")),
					  aes(y = sector, fill = sector)) +
	geom_boxplot(aes(xmin = P1, xlower = P25, xmiddle = P50, xupper = P75, xmax = P99), stat = "identity") +
	geom_point(aes(x = Mean)) +
	facet_wrap(~name, scales = "free_y", nrow = 4) +
	scale_fill_viridis_d(alpha = 0.7) +
	scale_x_continuous(trans = "log10", labels = scales::label_comma(), n.breaks = 6) +
	scale_y_discrete(labels = NULL, breaks = NULL, limits = rev) +
	labs(x = NULL, y = NULL, fill = NULL) +
	theme_bw()
all_exp_firms <- ggplot(tab34_data %>% filter(group == "all", trade == "exp", str_detect(name, "Extensive")),
					  aes(y = sector, fill = sector)) +
	geom_boxplot(aes(xmin = P1, xlower = P25, xmiddle = P50, xupper = P75, xmax = P99), stat = "identity") +
	geom_point(aes(x = Mean)) +
	facet_wrap(~name, scales = "free_y", nrow = 4) +
	scale_fill_viridis_d(alpha = 0.7) +
	scale_x_continuous(trans = "log10", labels = scales::label_comma(), n.breaks = 7) +
	scale_y_discrete(labels = NULL, breaks = NULL, limits = rev) +
	labs(x = NULL, y = NULL, fill = NULL) +
	theme_bw()
ggarrange(all_exp_val, all_exp_firms, ncol = 2, common.legend = TRUE, legend = "bottom")
ggsave("clean_output/plots/figure11.png", width = 10, height = 7, dpi = 300)


## Table 4
# Plot
all_imp_val <- ggplot(tab34_data %>% filter(group == "all", trade == "imp", str_detect(name, "Intensive")),
	   aes(y = sector, fill = sector)) +
	geom_boxplot(aes(xmin = P1, xlower = P25, xmiddle = P50, xupper = P75, xmax = P99), stat = "identity") +
	geom_point(aes(x = Mean)) +
	facet_wrap(~name, scales = "free_y", nrow = 4) +
	scale_fill_viridis_d(alpha = 0.7) +
	scale_x_continuous(trans = "log10", labels = scales::label_comma(), n.breaks = 6) +
	scale_y_discrete(labels = NULL, breaks = NULL, limits = rev) +
	labs(x = NULL, y = NULL, fill = NULL) +
	theme_bw()
all_imp_firms <- ggplot(tab34_data %>% filter(group == "all", trade == "imp", str_detect(name, "Extensive")),
					  aes(y = sector, fill = sector)) +
	geom_boxplot(aes(xmin = P1, xlower = P25, xmiddle = P50, xupper = P75, xmax = P99), stat = "identity") +
	geom_point(aes(x = Mean)) +
	facet_wrap(~name, scales = "free_y", nrow = 4) +
	scale_fill_viridis_d(alpha = 0.7) +
	scale_x_continuous(trans = "log10", labels = scales::label_comma(), n.breaks = 6) +
	scale_y_discrete(labels = NULL, breaks = NULL, limits = rev) +
	labs(x = NULL, y = NULL, fill = NULL) +
	theme_bw()
ggarrange(all_imp_val, all_imp_firms, ncol = 2, common.legend = TRUE, legend = "bottom")
ggsave("clean_output/plots/figure12.png",  width = 10, height = 7, dpi = 300)


